==> kotlin-compiler-embeddable-0.14.449-sources.jar: org/jetbrains/kotlin/extensions/ProjectExtensionDescriptor.kt <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.extensions

import com.intellij.openapi.extensions.ExtensionPointName
import com.intellij.openapi.project.Project
import com.intellij.openapi.extensions.ExtensionPoint
import com.intellij.openapi.extensions.Extensions

public open class ProjectExtensionDescriptor<T>(name: String, private val extensionClass: Class<T>) {
    public val extensionPointName: ExtensionPointName<T> = ExtensionPointName.create(name)!!

    public fun registerExtensionPoint(project: Project) {
        Extensions.getArea(project).registerExtensionPoint(
                extensionPointName.getName()!!,
                extensionClass.getName(),
                ExtensionPoint.Kind.INTERFACE
        )
    }

    public fun registerExtension(project: Project, extension: T) {
        Extensions.getArea(project).getExtensionPoint(extensionPointName).registerExtension(extension)
    }

    public fun getInstances(project: Project): Collection<T> {
        val projectArea = Extensions.getArea(project)
        if (!projectArea.hasExtensionPoint(extensionPointName.getName()!!)) return listOf()

        return projectArea.getExtensionPoint(extensionPointName).getExtensions().toList()
    }
}

==> kotlin-compiler-embeddable-1.0.7-sources.jar: org/jetbrains/kotlin/extensions/ProjectExtensionDescriptor.kt <==
/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.extensions

import com.intellij.openapi.extensions.ExtensionPointName
import com.intellij.openapi.project.Project
import com.intellij.openapi.extensions.ExtensionPoint
import com.intellij.openapi.extensions.Extensions

open class ProjectExtensionDescriptor<T>(name: String, private val extensionClass: Class<T>) {
    val extensionPointName: ExtensionPointName<T> = ExtensionPointName.create(name)!!

    fun registerExtensionPoint(project: Project) {
        Extensions.getArea(project).registerExtensionPoint(
                extensionPointName.name!!,
                extensionClass.name,
                ExtensionPoint.Kind.INTERFACE
        )
    }

    fun registerExtension(project: Project, extension: T) {
        Extensions.getArea(project).getExtensionPoint(extensionPointName).registerExtension(extension)
    }

    fun getInstances(project: Project): Collection<T> {
        val projectArea = Extensions.getArea(project)
        if (!projectArea.hasExtensionPoint(extensionPointName.name!!)) return listOf()

        return projectArea.getExtensionPoint(extensionPointName).extensions.toList()
    }
}
